from itertools import product
import click
import json


def get_entities(file_obj): # <1>
    json_obj = json.load(file_obj)
    return (entity['name'] for entity in json_obj['entities'])


def prompt_for_needs(entities): # <2>
    needs = click.prompt(' x '.join(entities),
                         default='', show_default=False)
    return {'entities': entities,
            'attributes': [need.strip() for need in needs.split(',')
                           if need.strip() != '']}


@click.command()
@click.option('--output', '-o', type=click.File('w'))
@click.argument('entity_file', nargs=-1, type=click.File('r'))
def map_needs(output, entity_file): # <3>
    cartesian_product = product(*map(get_entities, entity_file))
    results = map(prompt_for_needs, cartesian_product)
    json.dump({'needs': list(results)}, output, indent=4)
    

if __name__ == '__main__':
    map_needs()

