from operator import itemgetter
import click
import math
import json


def get_combined_value(assessments, picks): # <1>
    power_up = (assessments.get(pick, 0)**2 for pick in picks)
    return math.sqrt(sum(power_up))


def get_entity_values(file_obj, picks): # <2>
    json_obj = json.load(file_obj)
    return {entity['name']: get_combined_value(entity['assessments'], picks)
             for entity in json_obj['entities']}


@click.command()
@click.option('--assessment', '-a', multiple=True)
@click.argument('configuration_file', type=click.File('r'))
def prioritize_entities(assessment, configuration_file): # <3>
    entities = get_entity_values(configuration_file, assessment)

    for index, (name, importance) in enumerate( # <4>
            sorted(entities.items(), reverse=True, key=itemgetter(1)),
            start=1):
        print('{index}. {name} ({importance})'.format(
            index=index, name=name, importance=round(importance,1)))


if __name__ == '__main__':
    prioritize_entities()
