from prioritize_entities import get_combined_value, get_entity_values
from operator import itemgetter
import click
import math
import json


def get_entity_priorities(entity_file_objects, picks): # <1>
    return {name: priority
            for file_obj in entity_file_objects
            for name, priority in get_entity_values(file_obj, picks).items()}


def get_attribute_priorities(mapfile, priorities): # <2>
    json_obj = json.load(mapfile)
    results = {} 
    for need in json_obj['needs']:
        for attribute in need['attributes']:
            results[attribute] = max(
                results.get(attribute,0),
                get_combined_value(priorities, need['entities']))

    return results


@click.command()
@click.option('--mapfile', '-m', type=click.File('r'))
@click.option('--assessment', '-a', multiple=True)
@click.argument('entity_file', nargs=-1, type=click.File('r'))
def prioritize_needs(mapfile, assessment, entity_file): # <3>
    priorities = get_entity_priorities(entity_file, assessment)
    needs = get_attribute_priorities(mapfile, priorities)
    for idx, (name, priority) in enumerate(sorted(needs.items(),reverse=True,
                                                  key=itemgetter(1)), start=1):
        print('{index}. {name} ({priority})'.format(
            index=idx, name=name, priority=round(priority,1)))


if __name__ == '__main__':
    prioritize_needs()
