from sqlalchemy import create_engine, MetaData, Table, Column, select, func
from sqlalchemy.dialects import postgresql
from os import environ as env
import click


@click.command()
@click.option('--critical', '-c', type=int)  # <1>
def check_availability(critical):
    database = env.get('PRIMARY_DB')  # <2>
    engine = create_engine(database)  # <3>
    meta = MetaData()

    replication = Table('pg_stat_replication', meta,  # <4>
                        Column('client_addr', postgresql.INET))

    sql_statement = select([func.count(replication.c.client_addr)])  # <5>
    replica_count = engine.execute(sql_statement).scalar()

    if replica_count < critical:  # <6>
        print('CRITICAL: Availability (only {count} replicas)'.format(
            count=replica_count))
        raise SystemExit(2)

    print('OK: Availability is ok')
    raise SystemExit(0)


if __name__ == '__main__':
    try:
        check_availability()
    except Exception as e:
        print('UNKNOWN: {0}'.format(e))
        raise SystemExit(3)
