from flask import Flask, render_template
import os.path
import yaml
import re


app = Flask(__name__)


def separate_blogpost(content): # <1>
    frontmatter = {}
    if content.startswith('---'):
        match = re.search(
            r'^(?P<yamlblock>---(?P<yaml>.*?)---[ \t]*\r?\n)', # <2>
            content, re.DOTALL)
        if match:
            frontmatter = yaml.load(match.group('yaml')) # <3>
            content = content[match.end('yamlblock'):]

    return (frontmatter, content)


@app.route('/')
def index():
    filedir = os.path.dirname(__file__)
    blogpath = os.path.join(filedir, 'posts', 'blogpost.markdown')
    with open(blogpath) as blogfile:
        blog = blogfile.read()

    (front, content) = separate_blogpost(blog)
    preview_post = '# {title}\n{content}'.format(title=front['Title'],
                                                   content=content)
    
    return render_template('index.html', post=preview_post)
