import datetime
import click
import csv

@click.command()
@click.option('--critical', '-c', type=float)
@click.option('--days', '-d', type=int)
@click.argument('records_file', type=click.File('r'))
def check_timeliness(critical, days, records_file):
    today = datetime.date.today()
    start_date = str(today-datetime.timedelta(days=days)) # <1>
    
    late_outputs = [row['timeliness'] == 'late' # <2>
                    for row in csv.DictReader(records_file)
                    if row['date'] >= start_date]

    if len(late_outputs): # <3>
        percent_late = sum(late_outputs) * 100 / float(len(late_outputs))
    else:
        percent_late = 0

    if percent_late > critical: # <4>
        print('CRITICAL: {percent}% of processed outputs were late'.format(
            percent=round(percent_late)))
        raise SystemExit(2)

    print('OK: Timeliness')
    raise SystemExit(0)


if __name__ == '__main__':
    try:
        check_timeliness()
    except Exception as e:
        print('UNKNOWN: {0}'.format(e))
        raise SystemExit(3)
