from jinja2 import Environment, FileSystemLoader
from urllib.parse import urljoin
import os.path
import click
import csv


def extract(file_obj):
    csv_reader = csv.DictReader(file_obj)
    return (row for row in csv_reader)


def transform(rows):
    for row in rows:
        row['description'] = urljoin('http://knowyourmeme.com/memes/',  # <1>
                                     row['description'])
        yield row


def load(rows):
    filedir = os.path.dirname(__file__)
    env = Environment(
        loader=FileSystemLoader(os.path.join(filedir, 'templates'))
        )

    template = env.get_template('memes.jinja2')
    content = template.render(memes=rows)

    with open('index.html', 'w') as outputfile:
        outputfile.write(content)


@click.command()
@click.argument('csvfile', nargs=1, type=click.File('r'))
def etl(csvfile):
    extracted_data = extract(csvfile)
    transform_data = transform(extracted_data)
    load(transform_data)

if __name__ == '__main__':
    etl()
