from original_etl import transform as original_transform # <1>
from later_etl import transform as later_transform
from later_etl import extract, load
from goodtables import validate
import itertools
import click

schema_map = [
    ('schemas/later_memes.json', later_transform), # <2>
    ('schemas/first_memes.json', original_transform)
]

def get_transform_function(csvfile_obj): # <3>
    for (schema, transform_function) in schema_map:
        if validate(csvfile_obj, schema=schema):
            return transform_function

    raise ValueError('Unable to find correct transform function')

def get_memes(file_obj): # <4>
    transform_function = get_transform_function(file_obj)
    extracted_data = extract(file_obj)
    return transform_function(extracted_data)


@click.command() # <5>
@click.argument('csvfile', nargs=-1, type=click.File('r'))
def reproducibility(csvfile):
    load(itertools.chain.from_iterable(
        [get_memes(file_obj) for file_obj in csvfile]))


if __name__ == '__main__':
    reproducibility()
