import contextlib
import pytest
import click
import io


@click.command()
@click.argument('testfile', type=click.Path(exists=True))
def check_reproducibility(testfile):
    test_output = io.StringIO() # <1>
    with contextlib.redirect_stdout(test_output): # <2>
        exit_code = pytest.main(['-q', testfile]) # <3>

    print(test_output.getvalue().splitlines()[-1]) # <4>

    if exit_code not in [0, 1]: # <5>
        raise SystemExit(3)

    raise SystemExit(2*exit_code) # <6>


if __name__ == '__main__':
    try:
        check_reproducibility()
    except Exception as e:
        print('UNKNOWN: {0}'.format(e))
        raise SystemExit(3)
