import subprocess
import os.path
import click


@click.command()
@click.option('--critical', '-c', type=int)
@click.option('--warning', '-w', type=int)
@click.option('--reference', '-r', type=click.Path(exists=True))
@click.option('--schema', '-s', type=click.Path(exists=True))
@click.argument('descriptor', type=click.Path(exists=True))
def qualitycontrol(critical, warning, reference, schema, descriptor):
    filedir = os.path.dirname(__file__)
    checks = ( # <1>
        ("python", os.path.join(filedir, "check_metadata_completeness.py"),
         "-s", schema, "-d", descriptor),
        ("python", os.path.join(filedir, "check_data_completeness.py"),
         "-r", reference, "-d", descriptor),
    )

    error_count = sum([int(subprocess.check_output(check)) # <2>
                       for check in checks])

    if error_count >= critical:
        print('CRITICAL: Completeness ({count} errors found)'.format(
            count=error_count))
        raise SystemExit(2)

    if error_count >= warning:
        print('WARNING: Completeness ({count} errors found)'.format(
            count=error_count))
        raise SystemExit(1)

    print('OK: Completeness')
    raise SystemExit(0)


if __name__ == '__main__':
    try:
        qualitycontrol()
    except Exception as e:
        print('UNKNOWN: {0}'.format(e))
        raise SystemExit(3)
