from urllib.parse import urljoin, urlunsplit
from datapackage import Package
import click


@click.command()
@click.option('--reference', '-r', type=click.File('r'), required=True)
@click.option('--critical','-c', type=int, default=1)
@click.option('--warning', '-w', type=int, default=1)
@click.option('--dryrun', '-d', is_flag=True)
@click.argument('descriptor', type=click.Path(exists=True))
def qualitycontrol(reference, critical, warning, dryrun, descriptor):
    genders = set([row.strip().lower() for row in reference.readlines() # <1>
                   if row.strip() != ''])

    package = Package(descriptor) # <2>
    genderdataset = package.get_resource('gender') # <3>

    genderdata = set([row['identity'].strip()  # <4>
                      for row in genderdataset.read(keyed=True)
                      if row['identity'].strip() != ''])

    error_count = len(genders - genderdata) # <5>

    if dryrun:
        print(error_count)
        raise SystemExit(0)

    if error_count >= critical:
        print('CRITICAL: Data completeness ({count} errors)'.format(
            count=error_count))
        raise SystemExit(2)

    if error_count >= warning:
        print('WARNING: Data completeness ({count} errors)'.format(
            count=error_count))
        raise SystemExit(1)

    print('OK: Data completeness ({count} errors)'.format(
        count=error_count))
    raise SystemExit(0)
        

if __name__ == '__main__':
    try:
        qualitycontrol()
    except Exception as e:
        print('UNKNOWN: {0}'.format(e))
        raise SystemExit(3)
