from urllib.parse import urlunsplit
import jsonschema
import click
import json


@click.command()
@click.option('--schema', '-s', type=click.File('r'), required=True)
@click.option('--critical','-c', type=int, default=1)
@click.option('--warning', '-w', type=int, default=1)
@click.option('--dryrun', '-d', is_flag=True) # <1>
@click.argument('descriptor', type=click.File('r'))
def qualitycontrol(schema, critical, warning, dryrun, descriptor):
    schema = json.load(schema) # <2>
    datapackage = json.load(descriptor) # <3>

    validator = jsonschema.Draft4Validator(schema) # <4>
    error_list = list(validator.iter_errors(datapackage)) # <5>
    error_count = len(error_list)

    if dryrun: # <6>
        print(error_count)
        raise SystemExit(0)

    if error_count >= critical: # <7>
        print('CRITICAL: Metadata completeness ({count} errors)'.format(
            count=error_list))
        raise SystemExit(2)

    if error_count >= warning: # <8>
        print('WARNING: Metadata completeness ({count} errors)'.format(
            count=error_count))
        raise SystemExit(1)

    print('OK: Metadata completeness ({count} errors)'.format(
        count=error_count)) # <9>
    raise SystemExit(0)


if __name__ == '__main__':
    try:
        qualitycontrol()
    except Exception as e:
        print('UNKNOWN: {0}'.format(e))
        raise SystemExit(3)
