from flask import Flask, render_template, request, redirect, session, \
    url_for, send_from_directory
from datetime import datetime
import uuid
import csv

app = Flask(__name__)
app.secret_key = 'the art of data usability secret key'


@app.route('/')
def home():
    userid = session.get('userid', None)
    if userid is None:
        return redirect(url_for('login'))        

    with open('/data/groups.csv') as groupfile:
        reader = csv.DictReader(groupfile)
        groups = filter(lambda row: row['user'] == userid, reader)
        return render_template('index.html', user=userid, groups=groups)


@app.route('/<group>', methods=['GET', 'POST'])
def group(group):
    userid = session.get('userid', None)
    if userid is None:
        return redirect(url_for('login'))

    with open('/data/groups.csv') as groupfile:
        reader = csv.DictReader(groupfile)
        if not any(map(lambda row: row['user'] == userid and row['group'] == group,
                       reader)):
            return redirect(url_for('home'))

    if request.method == 'POST':
        message = request.form.get('message', '...')
        with open('data/messages.csv', 'a') as messagefile:
            writer = csv.writer(messagefile)
            writer.writerow([userid, group, message])

    with open('/data/users.csv') as userfile:
        reader = csv.DictReader(userfile)
        users = {row['user']: row['username'] for row in reader} 
        
    with open('/data/messages.csv') as messagefile:
        reader = csv.DictReader(messagefile)
        messages = list(filter(lambda message: message['group'] == group,
                               reader))
        
    return render_template('group.html', user=userid, users=users, group=group,
                           messages=messages)


@app.route('/register', methods=['GET', 'POST'])
def register():
    if request.method == 'POST':
        username = request.form.get('username')
        userid = uuid.uuid4().hex
        with open('/data/users.csv', 'a') as userfile:
            writer = csv.writer(userfile)
            writer.writerow([userid, username])
        session['userid'] = userid
        
        hashtags = map(
            lambda group: group.lstrip('#').strip().lower(),
            set(request.form.get('hashtags').split()))

        with open('/data/groups.csv', 'a') as groupfile:
            writer = csv.writer(groupfile)
            for hashtag in hashtags:
                writer.writerow([userid, hashtag])
        return redirect('/')
    return render_template('register.html')


@app.route('/login', methods=['GET', 'POST'])
def login():
    if request.method == 'POST':
        username = request.form.get('username')
        with open('/data/users.csv') as userfile:
            reader = csv.DictReader(userfile)
            for row in reader:
                if row['username'] == username:
                    session['userid'] = row['user']
                    break
        return redirect('/')
    else:
        return render_template('login.html')


@app.route('/logout', methods=['POST'])
def logout():
    if 'userid' in session:
        del session['userid']
    return redirect('/')

def deleteuserfromfile(userid, filename):
    with open(filename, 'r+') as datafile:
        reader = csv.DictReader(datafile)
        users = list(filter(lambda user: user['user'] != userid, reader))
        datafile.seek(0)
        writer = csv.DictWriter(datafile, fieldnames=reader.fieldnames)
        writer.writeheader()
        writer.writerows(users)
        datafile.truncate()

def deleteuser(userid):
        for filename in ('users.csv', 'groups.csv', 'messages.csv'):
            deleteuserfromfile(userid,
                               '/data/{filename}'.format(filename=filename))

        with open('/data/csvirc.log', 'a') as logfile:
            logfile.write('DELETED {user} at {timestamp}\n'.format(
                user=userid, timestamp=datetime.now()))
        del session['userid']

        
@app.route('/remove', methods=['GET', 'POST'])
def remove():
    userid = session.get('userid', None)
    if userid is None:
        return redirect(url_for('login'))        

    if request.method == 'POST':
        with open('/data/erasure.csv', 'a') as erasurefile:
            writer = csv.writer(erasurefile)
            writer.writerow([datetime.now(), userid])

        deleteuser(userid)
        return redirect('/')

    with open('/data/users.csv') as userfile:
        reader = csv.DictReader(userfile)
        user = next(filter(lambda user: user['user'] == userid, reader))
        
    return render_template('delete.html',
                           username=user.get('username','somebody'))

@app.route('/data/<path:filename>')
def data(filename):
    return send_from_directory('/data', filename)
