import click
import csv


@click.command()
@click.option('--critical', '-c', type=int)
@click.option('--logfile', '-l')
@click.argument('erasures')
def check_auditability(critical, logfile, erasures):
    removed_users = {} # <1>
    with open(logfile) as log: # <2>
        for line in log.readlines():
            (action, user) = line.split()[0:2] # <3>
            if action.lower() == 'deleted':
                removed_users[user] = True

    with open(erasures) as erasurefile:  # <4>
        reader = csv.DictReader(erasurefile)

        error_count = sum([row['userid'] not in removed_users # <5>
                           for row in reader])

    if error_count >= critical: # <6>
        print('CRITICAL: Forgetability ({count} requests remaining)'.format(
            count=error_count))
        raise SystemExit(2)

    print('OK: Forgetability') # <7>
    raise SystemExit(0)


if __name__ == '__main__':
    try:
        check_auditability()
    except Exception as e:
        print('UNKNOWN: {0}'.format(e))
        raise SystemExit(3)
