from flask import Flask, jsonify, render_template
from collections import defaultdict
from urllib.parse import urljoin
from os import environ as env
import requests
import urllib3


app = Flask(__name__)
urllib3.disable_warnings()

app.config['ICINGAHOST'] = env.get('ICINGAHOST', 'https://monitor:5665')
app.config['ICINGAUSER'] = env.get('ICINGAUSER', 'apiuser')
app.config['ICINGAPASS'] = env.get('ICINGAPASS', 'badpassword')


@app.route('/')
def dashboard():
    return render_template('index.html')


@app.route('/status')
def status():
    url = urljoin(app.config.get('ICINGAHOST'), '/v1/objects/services')
    data = {"joins": [ "host.name" ], "attrs": [ "name", "state" ]}

    response = requests.get(
        url, json=data,
        auth=(app.config.get('ICINGAUSER'), app.config.get('ICINGAPASS')),
        verify=False)

    if not response.ok:
        raise IOError(response.text)

    json = response.json()

    STATUS = {0: 'ok', 1: 'warning', 2: 'critical', 3: 'unknown'}

    services = defaultdict(dict)
    for service in json['results']:
        host = service.get('joins', {}).get('host', {}).get('name', 'host?')
        name = service.get('attrs', {}).get('name', 'service?')
        status = STATUS.get(
            int(service.get('attrs', {}).get('state', 3)), 'unknown')

        services[host][name] = status;

    return jsonify(services)
