import numpy
import click
import csv


def get_ratio_within_limit(mean, standard_deviation, datapoints):
    lower_limit = mean - standard_deviation
    upper_limit = mean + standard_deviation
    
    within = filter(lambda d: lower_limit <= d <= upper_limit, datapoints) # <1>
    return len(list(within)) / len(datapoints)


@click.command()
@click.option('--critical', '-c', type=float)
@click.argument('filepath', type=click.Path(exists=True))
def check_normality(critical, filepath):
    with open(filepath, 'r') as csv_file: # <2>
        reader = csv.reader(csv_file)
        datapoints = list(map(lambda datapoint: float(datapoint[0]), reader))

    mean = numpy.mean(datapoints) # <3>
    standard_deviation = numpy.std(datapoints) # <4>

    normality_limits = {1: 0.68, 2: 0.95, 3: 0.997} # <5>

    criticals = []
    for limit, expected_ratio in normality_limits.items(): # <6>
        ratio_within = get_ratio_within_limit(mean, limit*standard_deviation,
                                              datapoints)
        if ratio_within < expected_ratio - critical: # <7>
            criticals.append((ratio_within, expected_ratio))

    if criticals: # <8>
        print('CRITICAL: {path} not normally distributed '\
              '{criticals}'.format(path=filepath, criticals=criticals))
        raise SystemExit(2)

    print('Normality: OK')
    raise SystemExit(0)


if __name__ == '__main__':
    try:
        check_normality()
    except Exception as e:
        print('UNKNOWN: {0}'.format(e))
        raise SystemExit(3)
